#region Copyright
// Copyright Syncfusion Inc. 2001 - 2009. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace TreeGridListHelper
{
    [ToolboxData("<{0}:TreeGridTemplateControl runat=server></{0}:TreeGridTemplateControl>")]
    public class TreeGridTemplateControl : WebControl, IPostBackEventHandler
    {
        private bool expanded;
        private int level;
        private int rowIndex;

        private string text;


        public event ClickHandler Click;

        [Bindable(true)]
        [Category("Appearance")]
        [DefaultValue(true)]
        [Localizable(true)]
        public bool Expanded
        {
            get
            {
                return expanded;
            }

            set
            {
                expanded = value;
            }
        }

        [Bindable(true)]
        [Category("Appearance")]
        [DefaultValue("")]
        [Localizable(true)]
        public int Level
        {
            get
            {
                return level;
            }

            set
            {
                level = value;
            }
        }

        private string nodeIndent
        {
            get
            {
                return (((this.Level + 1) * 10).ToString());
            }
        }

        public int RowIndex
        {
            get { return rowIndex; }
            set { rowIndex = value; }
        }

        [Bindable(true)]
        [Category("Appearance")]
        [DefaultValue("")]
        [Localizable(true)]
        public string Text
        {
            get
            {
                return text;
            }

            set
            {
                text = value;
            }
        }

        void IPostBackEventHandler.RaisePostBackEvent(string args)
        {
            RaisePostBackEvent(args);
        }

        public virtual void RaisePostBackEvent(string eventArgument)
        {
            //f argument is True, then make it as false and viceversa.
            this.Expanded = (eventArgument.Split('|')[1] == "True") ? false : true;
            int rowIndex = Convert.ToInt32(eventArgument.Split('|')[0]);
            if (Click != null)
            {
                Click(this, new ClickEventArgs(rowIndex, this.Expanded));
            }
            return;
        }

        protected override void RenderContents(HtmlTextWriter writer)
        {
            string code = "UpdateGrid(this.id,{1}, '{2}');";
            writer.AddAttribute("onclick", Page.GetPostBackClientEvent(this, string.Format("{0}|{1}", this.RowIndex, this.Expanded)));
            //writer.AddAttribute("onclick", "debugger;UpdateGrid(this.parentNode.parentNode.parentNode,'" + this.Expanded + "')");
            //writer.AddAttribute("onclick", "javascript:" + Page.GetPostBackEventReference(this, this.Level.ToString() + "|" + this.Expanded.ToString()));
            writer.AddStyleAttribute(HtmlTextWriterStyle.PaddingLeft, nodeIndent + "px");
            writer.RenderBeginTag(HtmlTextWriterTag.Div);
            writer.AddAttribute("src", this.Expanded ? "../images/exp.gif" : "../images/col.gif");
            writer.AddStyleAttribute(HtmlTextWriterStyle.Width, "17px");
            writer.AddStyleAttribute(HtmlTextWriterStyle.Height, "15px");
            writer.AddStyleAttribute(HtmlTextWriterStyle.VerticalAlign, "middle");
            writer.RenderBeginTag(HtmlTextWriterTag.Img);
            writer.RenderEndTag();
            writer.Write("{0}", this.Text);
            writer.RenderEndTag();
            Page.ClientScript.GetPostBackEventReference(this, "TreeColumnTemplateControl");
        }

        #region Variables


        #endregion

        #region Properties


        #endregion

        #region Overrides

        #endregion

        #region PostbackEvents


        #endregion

    }

    #region EventHandler

    public delegate void ClickHandler(object sender, ClickEventArgs args);

    #endregion

    #region EventArgs

    public class ClickEventArgs : EventArgs
    {

        private bool _expanded;
        private int index;

        public ClickEventArgs(int _index, bool expanded)
        {
            index = _index;
            _expanded = expanded;
        }

        public bool Expanded
        {
            get { return _expanded; }
        }

        public int RowIndex
        {
            get { return index; }
        }
    }

    #endregion
}
